@@ -29,7 +29,6 @@ class Agent(AbstractObject):
         Attribute('password'),
         Attribute('number', required=True),
         Attribute('context', required=True),
-        Attribute('wrapuptime', required=True, default='0'),
         Attribute('users', default_factory=list),
     ]
 
@@ -40,15 +39,10 @@ class Agent(AbstractObject):
     def _to_agentfeatures(self, obj_dict):
         agentfeatures = {
             'numgroup': '1',
-            'musiconhold': 'default',
-            'ackcall': 'no',
-            'acceptdtmf': '#',
-            'enddtmf': '*',
             'autologoff': '0',
             'firstname': self.firstname,
             'number': self.number,
             'context': self.context,
-            'wrapuptime': self.wrapuptime
         }
         if self.lastname is not None:
             agentfeatures['lastname'] = self.lastname
@@ -73,8 +67,6 @@ class Agent(AbstractObject):
         self.password = agentfeatures['passwd']
         self.number = agentfeatures['number']
         self.context = agentfeatures['context']
-        if 'wrapuptime' in agentfeatures:
-            self.wrapuptime = agentfeatures['wrapuptime']
 
     def _from_usermember(self, usermember):
         if usermember:
